=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2005-10-19 06:11:31 +0000
+++ bzrlib/commands.py	2005-10-19 06:44:53 +0000
@@ -450,9 +450,6 @@
     --profile
         Run under the Python profiler.
     """
-    import bzrlib.transport
-    bzrlib.transport.register_builtin_transports()
-    
     argv = [a.decode(bzrlib.user_encoding) for a in argv]
 
     opt_profile = opt_no_plugins = opt_builtin = False

=== modified file 'bzrlib/transport/__init__.py'
--- bzrlib/transport/__init__.py	2005-10-19 06:11:31 +0000
+++ bzrlib/transport/__init__.py	2005-10-19 06:44:53 +0000
@@ -354,15 +354,22 @@
     # which has a lookup of None
     return _protocol_handlers[None](base)
 
-# Local transport should always be initialized
-import bzrlib.transport.local
-
-
-def register_builtin_transports():
-    """Register all builtin transport modules.
+
+def register_lazy_transport(scheme, module, classname):
+    """Register lazy-loaded transport class.
+
+    When opening a URL with the given scheme, load the module and then
+    instantiate the particular class.  
+    """
+    def _loader(base):
+        mod = __import__(module, globals(), locals(), [classname])
+        klass = getattr(mod, classname)
+        return klass(base)
+    register_transport(scheme, _loader)
     
-    This happens as a sideeffect of importing the modules.
-    """
-    import bzrlib.transport.local, \
-           bzrlib.transport.http, \
-           bzrlib.transport.sftp
+# If nothing else matches, try the LocalTransport
+register_lazy_transport(None, 'bzrlib.transport.local', 'LocalTransport')
+register_lazy_transport('file://', 'bzrlib.transport.local', 'LocalTransport')
+register_lazy_transport('sftp://', 'bzrlib.transport.sftp', 'SFTPTransport')
+register_lazy_transport('http://', 'bzrlib.transport.http', 'HttpTransport')
+register_lazy_transport('https://', 'bzrlib.transport.http', 'HttpTransport')

=== modified file 'bzrlib/transport/http.py'
--- bzrlib/transport/http.py	2005-10-18 06:30:47 +0000
+++ bzrlib/transport/http.py	2005-10-19 06:44:53 +0000
@@ -221,6 +221,3 @@
         :return: A lock object, which should be passed to Transport.unlock()
         """
         raise TransportNotPossible('http does not support lock_write()')
-
-register_transport('http://', HttpTransport)
-register_transport('https://', HttpTransport)

=== modified file 'bzrlib/transport/local.py'
--- bzrlib/transport/local.py	2005-10-18 06:30:47 +0000
+++ bzrlib/transport/local.py	2005-10-19 06:44:53 +0000
@@ -243,7 +243,3 @@
     def __del__(self):
         shutil.rmtree(self.base, ignore_errors=True)
         mutter("%r destroyed" % self)
-
-# If nothing else matches, try the LocalTransport
-register_transport(None, LocalTransport)
-register_transport('file://', LocalTransport)

=== modified file 'bzrlib/transport/sftp.py'
--- bzrlib/transport/sftp.py	2005-10-19 05:03:45 +0000
+++ bzrlib/transport/sftp.py	2005-10-19 06:44:53 +0000
@@ -14,9 +14,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-"""
-Implementation of Transport over SFTP, using paramiko.
-"""
+"""Implementation of Transport over SFTP, using paramiko."""
 
 import getpass
 import os
@@ -32,7 +30,7 @@
 try:
     import paramiko
 except ImportError:
-    error('The SFTP plugin requires paramiko.')
+    error('The SFTP transport requires paramiko.')
     raise
 
 
@@ -443,7 +441,3 @@
         except IOError:
             pass
         return False
-
-
-register_transport('sftp://', SFTPTransport)
-

